crabnet.data.benchmark\_data.mp\_mu\_b package
==============================================

Module contents
---------------

.. automodule:: crabnet.data.benchmark_data.mp_mu_b
   :members:
   :undoc-members:
   :show-inheritance:
